==> tine20-tasks_2020.03.4.tar.bz2: Tasks/js/Tasks-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0 - Tasks\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Do you really want to delete the selected task?"
 ,"Do you really want to delete the selected tasks?"

]
, "Tags"
: "Tags"

, "Lead name"
: "Lead name"

, "Summary"
: "Summary"

, "Add a task..."
: "Add a task..."

, "Due Date"
: "Due Date"

, "Priority"
: "Priority"

, "Percent"
: "Percent"

, "Status, Status"
: [
  "Status"
 ,"Status"

]
, "Completed"
: "Completed"

, "Responsible"
: "Responsible"

, "Add New Task"
: "Add New Task"

, "You have to supply a due date, because an alarm ist set!"
: "You have to supply a due date, because an alarm ist set!"

, "Due date"
: "Due date"

, "Organizer"
: "Organizer"

, "Add Responsible ..."
: "Add Responsible ..."

, "Notes"
: "Notes"

, "Enter description..."
: "Enter description..."

, "Percentage"
: "Percentage"

, "Task, Tasks"
: [
  "Task"
 ,"Tasks"

]
, "Tasks"
: "Tasks"

, "to do list, to do lists"
: [
  "to do list"
 ,"to do lists"

]
, "to do lists"
: "to do lists"

, "Quick Search"
: "Quick Search"

, "Last Modified Time"
: "Last Modified Time"

, "Last Modified By"
: "Last Modified By"

, "Creation Time"
: "Creation Time"

, "Created By"
: "Created By"

, "New Task"
: "New Task"

, "Notification for Task "
: "Notification for Task "

, "Tasks status available"
: "Tasks status available"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."

, "No response"
: "No response"

, "Cancelled"
: "Cancelled"

, "In process"
: "In process"

, "Task priorities available"
: "Task priorities available"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."

, "low"
: "low"

, "normal"
: "normal"

, "high"
: "high"

, "urgent"
: "urgent"

, "All tasks of my taskslists"
: "All tasks of my taskslists"

, "My open tasks"
: "My open tasks"

, "My open tasks this week"
: "My open tasks this week"

, "All tasks for me"
: "All tasks for me"

, "All tasks that I am responsible for"
: "All tasks that I am responsible for"

, "Last modified by me"
: "Last modified by me"

, "All tasks that I have last modified"
: "All tasks that I have last modified"

, "Tasks without responsible"
: "Tasks without responsible"

, "%s's personal tasks"
: "%s's personal tasks"

, "manage shared task lists"
: "manage shared task lists"

, "Create new shared tasks lists"
: "Create new shared tasks lists"

, "manage shared tasks favorites"
: "manage shared tasks favorites"

, "Create or update shared tasks favorites"
: "Create or update shared tasks favorites"

, "Due"
: "Due"

, "Description"
: "Description"

, "Lead"
: "Lead"

, "Telephone"
: "Telephone"

, "Email"
: "Email"

, "All my tasks"
: "All my tasks"

, "Default Favorite"
: "Default Favorite"

, "The default favorite which is loaded on Tasks startup"
: "The default favorite which is loaded on Tasks startup"

, "Default Task List"
: "Default Task List"

, "The default task list to create new tasks in."
: "The default task list to create new tasks in."

, "Enable Standard Alarm"
: "Enable Standard Alarm"

, "New task get a standard alarm as defined below"
: "New task get a standard alarm as defined below"

, "Minutes before the task ends"
: "Minutes before the task ends"

, "Standard Alarm Time"
: "Standard Alarm Time"
, "Do you really want to delete the selected task?"
: "Do you really want to delete the selected task?"

, "Status"
: "Status"

, "Task"
: "Task"

, "to do list"
: "to do list"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-tasks_2024.11-2024.03.14.1.tar.bz2: Tasks/js/Tasks-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0 - Tasks\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Add New Task"
: "Add New Task"

, "You have to supply a due date, because an alarm ist set!"
: "You have to supply a due date, because an alarm ist set!"

, "Summary"
: "Summary"

, "Due date"
: "Due date"

, "Priority"
: "Priority"

, "Organizer / Responsible"
: "Organizer / Responsible"

, "Add Responsible ..."
: "Add Responsible ..."

, "Notes"
: "Notes"

, "Enter description..."
: "Enter description..."

, "Percentage"
: "Percentage"

, "Status, Status"
: [
  "Status"
 ,"Status"

]
, "Completed"
: "Completed"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Do you really want to delete the selected task?"
 ,"Do you really want to delete the selected tasks?"

]
, "Attachments"
: "Attachments"

, "Tags"
: "Tags"

, "Lead name"
: "Lead name"

, "Add a task..."
: "Add a task..."

, "Due Date"
: "Due Date"

, "Percent"
: "Percent"

, "Responsible"
: "Responsible"

, "Task, Tasks"
: [
  "Task"
 ,"Tasks"

]
, "Tasks"
: "Tasks"

, "to do list, to do lists"
: [
  "to do list"
 ,"to do lists"

]
, "to do lists"
: "to do lists"

, "Quick Search"
: "Quick Search"

, "Last Modified Time"
: "Last Modified Time"

, "Last Modified By"
: "Last Modified By"

, "Creation Time"
: "Creation Time"

, "Created By"
: "Created By"

, "New Task"
: "New Task"

, "All my tasks"
: "All my tasks"

, "Default Favorite"
: "Default Favorite"

, "The default favorite which is loaded on Tasks startup"
: "The default favorite which is loaded on Tasks startup"

, "Default Task List"
: "Default Task List"

, "The default task list to create new tasks in."
: "The default task list to create new tasks in."

, "Enable Standard Alarm"
: "Enable Standard Alarm"

, "New task get a standard alarm as defined below"
: "New task get a standard alarm as defined below"

, "Standard Alarm Time"
: "Standard Alarm Time"

, "Minutes before the task ends"
: "Minutes before the task ends"

, "Tasks status available"
: "Tasks status available"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."

, "No response"
: "No response"

, "Cancelled"
: "Cancelled"

, "In process"
: "In process"

, "Task priorities available"
: "Task priorities available"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."

, "low"
: "low"

, "normal"
: "normal"

, "high"
: "high"

, "urgent"
: "urgent"

, "%s's personal tasks"
: "%s's personal tasks"

, "GENDER_Task"
: "GENDER_Task"

, "Due"
: "Due"

, "Class"
: "Class"

, "Description"
: "Description"

, "Geo"
: "Geo"

, "Location"
: "Location"

, "Lead"
: "Lead"

, "Telephone"
: "Telephone"

, "Email"
: "Email"

, "Notification for Task %1$s"
: "Notification for Task %1$s"

, "All tasks of my taskslists"
: "All tasks of my taskslists"

, "My open tasks"
: "My open tasks"

, "My open tasks this week"
: "My open tasks this week"

, "All tasks for me"
: "All tasks for me"

, "All tasks that I am responsible for"
: "All tasks that I am responsible for"

, "Last modified by me"
: "Last modified by me"

, "All tasks that I have last modified"
: "All tasks that I have last modified"

, "Tasks without responsible"
: "Tasks without responsible"

, "manage shared task lists"
: "manage shared task lists"

, "Create new shared tasks lists"
: "Create new shared tasks lists"

, "manage shared tasks favorites"
: "manage shared tasks favorites"

, "Create or update shared tasks favorites"
: "Create or update shared tasks favorites"

, "Status"
: "Status"

, "Do you really want to delete the selected task?"
: "Do you really want to delete the selected task?"

, "Task"
: "Task"

, "to do list"
: "to do list"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
